@@ -7,6 +7,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	"github.com/aws/aws-sdk-go/aws"
+
 	"github.com/weaveworks/eksctl/pkg/git"
 )
 
@@ -108,6 +109,8 @@ func SetNodeGroupDefaults(ng *NodeGroup, meta *ClusterMeta) {
 	if ng.SecurityGroups.WithShared == nil {
 		ng.SecurityGroups.WithShared = Enabled()
 	}
+
+	setContainerRuntimeDefault(ng)
 }
 
 // SetManagedNodeGroupDefaults sets default values for a ManagedNodeGroup
@@ -188,6 +191,12 @@ func setVolumeDefaults(ng *NodeGroupBase, template *LaunchTemplate) {
 	}
 }
 
+func setContainerRuntimeDefault(ng *NodeGroup) {
+	if ng.ContainerRuntime == nil {
+		ng.ContainerRuntime = &DefaultContainerRuntime
+	}
+}
+
 func setIAMDefaults(iamConfig *NodeGroupIAM) {
 	if iamConfig.WithAddonPolicies.ImageBuilder == nil {
 		iamConfig.WithAddonPolicies.ImageBuilder = Disabled()
