@@ -22,6 +22,7 @@ type nodegroupOptions struct {
 	cmdutils.CreateManagedNGOptions
 	UpdateAuthConfigMap     bool
 	SkipOutdatedAddonsCheck bool
+	SubnetIDs               []string
 }
 
 func createNodeGroupCmd(cmd *cmdutils.Cmd) {
@@ -30,6 +31,10 @@ func createNodeGroupCmd(cmd *cmdutils.Cmd) {
 			return api.ErrInvalidName(ng.Name)
 		}
 
+		if options.SubnetIDs != nil {
+			ng.Subnets = append(ng.Subnets, options.SubnetIDs...)
+		}
+
 		ngFilter := filter.NewNodeGroupFilter()
 		if err := cmdutils.NewCreateNodeGroupLoader(cmd, ng, ngFilter, options.CreateNGOptions, options.CreateManagedNGOptions).Load(); err != nil {
 			return errors.Wrap(err, "couldn't create node group filter from command line options")
@@ -95,6 +100,7 @@ func createNodeGroupCmdWithRunFunc(cmd *cmdutils.Cmd, runFunc runFn) {
 		cmdutils.AddNodeGroupFilterFlags(fs, &cmd.Include, &cmd.Exclude)
 		cmdutils.AddUpdateAuthConfigMap(fs, &options.UpdateAuthConfigMap, "Add nodegroup IAM role to aws-auth configmap")
 		cmdutils.AddTimeoutFlag(fs, &cmd.ProviderConfig.WaitTimeout)
+		cmdutils.AddSubnetIDs(fs, &options.SubnetIDs, "Define an optional list of subnet IDs to create the nodegroup in")
 		fs.BoolVarP(&options.DryRun, "dry-run", "", false, "Dry-run mode that skips nodegroup creation and outputs a ClusterConfig")
 		fs.BoolVarP(&options.SkipOutdatedAddonsCheck, "skip-outdated-addons-check", "", false, "whether the creation of ARM nodegroups should proceed when the cluster addons are outdated")
 	})
