@@ -6,13 +6,11 @@ import (
 	"fmt"
 	"io"
 	"mime/multipart"
-	"path/filepath"
 	"strings"
 
 	"github.com/pkg/errors"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
-	"github.com/weaveworks/eksctl/pkg/nodebootstrap/bindata"
 )
 
 // ManagedAL2 is a bootstrapper for managed Amazon Linux 2 nodegroups
@@ -44,15 +42,6 @@ func (m *ManagedAL2) UserData() (string, error) {
 		cloudboot []string
 	)
 
-	if api.IsEnabled(ng.SSH.EnableSSM) {
-		installSSMScript, err := bindata.Asset(filepath.Join(dataDir, "install-ssm.al2.sh"))
-		if err != nil {
-			return "", err
-		}
-
-		scripts = append(scripts, string(installSSMScript))
-	}
-
 	if len(ng.PreBootstrapCommands) > 0 {
 		scripts = append(scripts, ng.PreBootstrapCommands...)
 	}
